# Biodiversity Intactness Index (BII)

The Biodiversity Intactness Index (BII) measures biodiversity change using abundance data on plants, fungi and animals worldwide. The Index shows how local terrestrial biodiversity responds to human pressures such as land use change and intensification. Generated by [Impact Observatory](https://www.impactobservatory.com/), in collaboration with [Vizzuality](https://www.vizzuality.com/), these datasets estimate terrestrial Biodiversity Intactness as 100-meter gridded maps for the years 2017-2020.  Biodiversity Intactness data is based on the [PREDICTS database](https://onlinelibrary.wiley.com/doi/full/10.1002/ece3.2579) of spatially referenced observations of biodiversity across 32,000 sites from over 750 studies

Biodiversity intactness is estimated as a combination of two metrics: Abundance, the quantity of individuals, and Compositional Similarity, how similar the composition of species is to an intact baseline. Linear mixed effects models are fit to estimate the predictive capacity of spatial datasets of human pressures on each of these metrics and project results spatially across the globe. These methods, as well as comparisons to other leading datasets and guidance on interpreting results, are further explained in a methods [white paper](https://ai4edatasetspublicassets.blob.core.windows.net/assets/pdfs/io-biodiversity/Biodiversity_Intactness_whitepaper.pdf) entitled “Global 100m Projections of Biodiversity Intactness for the years 2017-2020.”  authored by Francis Gassert, Joe Mazzarello, Sam Hyde.

#### Ancillary dataset Citation

```
Hudson, Lawrence N., Tim Newbold, Sara Contu, Samantha LL Hill, Igor Lysenko, Adriana De Palma, Helen RP Phillips et al. "The database of the
PREDICTS (projecting responses of ecological diversity in changing terrestrial systems) project." Ecology and evolution 7, no. 1 (2017): 145-188.
```

#### Dataset citation

```
Impact Observatory and Vizzuality. Biodiversity Intactness Index (BII) [Data set]. Retrieved from [URL of the dataset]
```

![bii](https://github.com/samapriya/awesome-gee-community-datasets/assets/6677629/e9fc5f5f-caf7-4300-be91-64b28a7c04c7)

#### Earth Engine Snippet

```js
var bdi_ic = ee.ImageCollection("projects/ebx-data/assets/earthblox/IO/BIOINTACT")
var bdi_2017_20_comp = bdi_ic.mean()
var bdi_2017_comp = bdi_ic.filterDate('2017-01-01', '2017-12-31').mean()


var visualization = {
  bands: ['BioIntactness'],
  min: 0,
  max: 1,
  palette: ['e5f5e0', 'a1d99b', '31a354'], 4: ['edf8e9', 'bae4b3', '74c476', '238b45']
};

Map.addLayer(bdi_2017_20_comp, visualization, "composite 2017-20")
Map.addLayer(bdi_2017_comp, visualization, "composite 2017")
```

Sample code: https://code.earthengine.google.com/?scriptPath=users/sat-io/awesome-gee-catalog-examples:/biodiversity-ecosystems-habitat/BIODIVERSITY-INTACTNESS-INDEX

#### License

The datasets are made available under the [CC BY 4.0 license](https://creativecommons.org/licenses/by/4.0/)

Keywords: Biodiversity, Ecology, Human Pressures, Gridded data

Dataset producer/licensor/processor: [Impact Observatory](https://www.impactobservatory.com/) and [Vizzuality ](https://www.vizzuality.com/)

Data hosted in Earth Engine by: [Earth Blox](https://www.earthblox.io/)
