# High Resolution Deterministic Precipitation Analysis (HRDPA)

The High Resolution Deterministic Precipitation Analysis (HRDPA) is a best estimate of 6 and 24 hour precipitation amounts. This objective estimate
integrates data from in situ precipitation gauge measurements, radar QPEs and a trial field generated by a numerical weather prediction system. CaPA
produces four analyses of 6 hour amounts per day, valid at synoptic hours (00, 06, 12 and 18 UTC) and two 24 hour analyses valid at 06 and 12 UTC.
HRDPA is provided by the Meterological Service of Canada (MSC), a part of Environment and Climate Change Canada (ECCC). The MSC provides weather
forecasts and warnings 24 hours a day, 365 days a year. MSC also provides federal department, agencies and other levels of government with
information to support emergency preparedness and response to events such as storms, floods, wildfires and other weather-related emergencies. The
model is based on the Canadian Precipitation Analysis (CaPA) system. You can find additional information [here](https://eccc-msc.github.io/open-data/msc-data/nwp_hrdpa/readme_hrdpa_en/) and information about the dataset can also be found on [climate engine org data page here](https://support.climateengine.org/article/67-hrdpa).

#### Dataset Description

**Spatial Information**

| Parameter            | Value                     |
|----------------------|---------------------------|
| Spatial extent       | Canada                    |
| Spatial resolution   | 2.5 km grid (1/24 deg)   |
| Temporal resolution  | Daily                     |
| Time span            | 2018-03-01 to present     |
| Update frequency     | Updated daily with 1 day lag time |

**Variables**

| Variable                  | Details                              |
|---------------------------|--------------------------------------|
| Precipitation ('Precipitation') | - Units: Millimeters                    |
|                           | - Scale factor: 1.0                    |

#### Citation

```
- [Canadian Precipitation Analysis (CaPA)](https://collaboration.cmc.ec.gc.ca/cmc/cmoi/product_guide/docs/lib/capa_information_leaflet_20141118_en.pdf) Methodology system

- Fortin, V., Roy, G., Stadnyk, T., Koenig, K., Gasset, N., & Mahidjiba, A. (2018). Ten years of science based on the Canadian precipitation analysis: A CaPA system overview and literature review. Atmosphere-Ocean, 56(3), 178-196.
```


#### Earth Engine Snippet

```js
// Read in Image Collections and get single image
var hrdpa_ic = ee.ImageCollection('projects/climate-engine-pro/assets/ce-hrdpa-daily')
var hrdpa_i = hrdpa_ic.first()

// Print single image to see bands
print(hrdpa_i)

// Visualize precipitation for single image
var prec_palette = ["#ffffcc", "#c7e9b4", "#7fcdbb", "#41b6c4", "#1d91c0", "#225ea8", "#0c2c84"]
Map.addLayer(hrdpa_i.select('precip'), {min: 0, max: 200, palette: prec_palette}, 'precip')
```

Sample code: https://code.earthengine.google.com/?scriptPath=users/sat-io/awesome-gee-catalog-examples:/weather-climate/CE-HRDPA-DAILY

#### License

Data are subject to the Government of Canada Open Data Licence Agreement: https://open.canada.ca/en/open-government-licence-canada. The terms of this Agreement govern your use and reproduction of the data instead of the copyright reproduction statements found in Important Notices on the Agriculture and Agri-Food Canada website.

Keywords: precipitation, Canada, near real-time, daily, climate

Dataset provided by: Environment and Climate Change Canada

Dataset curated in GEE by: Climate Engine Org
